@@ -86,6 +86,11 @@ PerfStat = NamedTuple('PerfStat', [('test_env', TestEnv),
 Baseline = NamedTuple('Baseline', [('perfStat', PerfStat),
                                    ('commit', GitHash)])
 
+# The type of exceptions which are thrown when computing the current stat value
+# fails.
+class StatsException(Exception):
+    pass
+
 class MetricChange(Enum):
     # The metric appears to have no baseline and is presumably a new test.
     NewMetric = 'NewMetric'
@@ -123,11 +128,6 @@ AllowedPerfChange = NamedTuple('AllowedPerfChange',
                                 ('opts', Dict[str, str])
                                 ])
 
-MetricBaselineOracle = Callable[[WayName, GitHash], Baseline]
-MetricDeviationOracle = Callable[[WayName, GitHash], Optional[float]]
-MetricOracles = NamedTuple("MetricOracles", [("baseline", MetricBaselineOracle),
-                                             ("deviation", MetricDeviationOracle)])
-
 def parse_perf_stat(stat_str: str) -> PerfStat:
     field_vals = stat_str.strip('\t').split('\t')
     stat = PerfStat(*field_vals) # type: ignore
@@ -645,7 +645,7 @@ def main() -> None:
     group.add_argument("--metric",
                        help="Test metric (one of " + str(testing_metrics()) + ").")
     group.add_argument("--way",
-                       help="Test way (one of " + str(testing_metrics()) + ").")
+                       help="Test way (for example, optasm).")
 
     group = parser.add_argument_group(title='Plotting', description="Plot historical performance metrics")
     group.add_argument("--chart", nargs='?', default=None, action='store', const='./PerformanceChart.html',
