@@ -4,7 +4,7 @@
 
 from my_typing import *
 from pathlib import Path
-from perf_notes import MetricChange, PerfStat, Baseline, MetricOracles, GitRef
+from perf_notes import MetricChange, PerfStat, Baseline, GitRef
 from datetime import datetime
 
 # -----------------------------------------------------------------------------
@@ -70,15 +70,6 @@ class TestConfig:
         # Was the compiler compiled with LLVM?
         self.ghc_built_by_llvm = False
 
-        # Should we print the summary?
-        # Disabling this is useful for Phabricator/Harbormaster
-        # logfiles, which are truncated to 30 lines. TODO. Revise if
-        # this is still true.
-        # Note that we have a separate flag for this, instead of
-        # overloading --verbose, as you might want to see the summary
-        # with --verbose=0.
-        self.no_print_summary = False
-
         # What platform are we running on?
         self.platform = ''
         self.os = ''
@@ -202,9 +193,6 @@ class TestConfig:
         # Baseline commit for performance metric comparisons.
         self.baseline_commit = None # type: Optional[GitRef]
 
-        # Additional package dbs to inspect for test dependencies.
-        self.test_package_db = [] # type: [PathToPackageDb]
-
         # Should we skip performance tests
         self.skip_perf_tests = False
 
@@ -225,6 +213,10 @@ class TestConfig:
         # See Note [Haddock runtime stats files] at the bottom of this file.
         self.stats_files_dir = Path('/please_set_stats_files_dir')
 
+        # Where to place observed output files on when unexpected output
+        # is observed.
+        self.unexpected_output_dir = None # type: Optional[Path]
+
         # Should we cleanup after test runs?
         self.cleanup = True
 
@@ -238,6 +230,9 @@ class TestConfig:
         # The path specifies the file in which to write the dependencies
         self.only_report_hadrian_deps = None # type: Optional[Path]
 
+        # Are we using GCC to preprocess C--?
+        self.cmm_cpp_is_gcc = False
+
     def validate(self) -> None:
         """ Check the TestConfig for self-consistency """
         def assert_implies(a: bool, b: bool):
@@ -360,6 +355,9 @@ class TestOptions:
        self.ignore_stdout = False
        self.ignore_stderr = False
 
+       # don't use the executable extension
+       self.ignore_extension = False
+
        # Backpack test
        self.compile_backpack = False
 
@@ -383,24 +381,20 @@ class TestOptions:
        # extra files to copy to the testdir
        self.extra_files = [] # type: List[str]
 
-       # Map from metric to (function from way and commit to baseline value, allowed percentage deviation) e.g.
-       #     { 'bytes allocated': (
-       #              lambda way commit:
-       #                    ...
-       #                    if way1: return None ...
-       #                    elif way2:return 9300000000 ...
-       #                    ...
-       #              , 10) }
-       # This means no baseline is available for way1. For way 2, allow a 10%
-       # deviation from 9300000000.
-       self.stats_range_fields = {} # type: Dict[MetricName, MetricOracles]
-
        # Is the test testing performance?
        self.is_stats_test = False
 
        # Does this test the compiler's performance as opposed to the generated code.
        self.is_compiler_stats_test = False
 
+       # Map from metric to information about that metric
+       #    { metric: { "deviation": <int>
+       #                The action to run to get the current value of the test
+       #              , "current": lambda way: <Int>
+       #                The action to run to get the baseline value of the test
+       #              , "baseline": lambda way, commit: baseline value } }
+       self.generic_stats_test: Dict  = {} # Dict
+
        # should we run this test alone, i.e. not run it in parallel with
        # any other threads
        self.alone = False
@@ -408,10 +402,11 @@ class TestOptions:
        # Does this test use a literate (.lhs) file?
        self.literate = False
 
-       # Does this test use a .c, .m or .mm file?
+       # Does this test use a .c, .cpp, .m or .mm file?
        self.c_src      = False
+       self.cxx_src    = False
        self.objc_src   = False
-       self.objcpp_src = False
+       self.objcxx_src = False
 
        # Does this test use a .cmm file?
        self.cmm_src    = False
@@ -422,6 +417,10 @@ class TestOptions:
        # Command to run before the test
        self.pre_cmd = None
 
+       # Optional per test target wrapper that overrides the default
+       # one when testing a cross target
+       self.target_wrapper = None
+
        # Command wrapper: a function to apply to the command before running it
        self.cmd_wrapper = None
 
@@ -445,14 +444,15 @@ class TestOptions:
        # Keep profiling callstacks.
        self.keep_prof_callstacks = False
 
-       # The directory the test is in
-       self.testdir = Path('.')
+       # The directory the test is run.
+       # Usually you should check the self.testdir property instead,
+       # which crashes when this is not initialised.
+       self.testdir_raw = None # type: Optional[Path]
 
        # Should we redirect stdout and stderr to a single file?
        self.combined_output = False
 
        # How should the timeout be adjusted on this test?
-       self.pre_cmd_timeout_multiplier = 1.0
        self.compile_timeout_multiplier = 1.0
        self.run_timeout_multiplier = 1.0
 
@@ -472,6 +472,12 @@ class TestOptions:
        # The extra hadrian dependencies we need for this particular test
        self.hadrian_deps = set(["test:ghc"]) # type: Set[str]
 
+   @property
+   def testdir(self) -> Path:
+       if self.testdir_raw is None:
+           raise Exception('testdir not initialized')
+       return self.testdir_raw
+
 # The default set of options
 global default_testopts
 default_testopts = TestOptions()
