@@ -1,6 +1,7 @@
 {-# LANGUAGE CPP,ForeignFunctionInterface #-}
 
 import Control.Concurrent
+import Data.Functor
 import Foreign.C
 import System.IO
 
@@ -8,8 +9,8 @@ import System.IO
 sleep n = sleepBlock (n*1000)
 foreign import stdcall safe "Sleep" sleepBlock :: Int -> IO ()
 #else
-sleep n = sleepBlock n
-foreign import ccall safe "sleep" sleepBlock :: Int -> IO ()
+sleep n = void $ sleepBlock n
+foreign import ccall safe "sleep" sleepBlock :: Int -> IO Int
 #endif
 
 main :: IO ()
