@@ -16,6 +16,7 @@ import System.Directory (removeFile)
 import System.Environment( getArgs )
 import qualified Data.Map as Map
 import Data.Dynamic ( fromDynamic,Dynamic )
+import Control.Monad.IO.Class
 
 main::IO()
 main = do
@@ -29,10 +30,11 @@ testOneFile libdir fileName = do
         let mn =mkModuleName fileName
         addTarget Target { targetId = TargetModule mn
                          , targetAllowObjCode = True
+                         , targetUnitId = homeUnitId_ dflags
                          , targetContents = Nothing }
         load LoadAllTargets
         modSum <- getModSummary mn
-        toks <- getRichTokenStream (ms_mod modSum)
+        toks <- liftIO $ getRichTokenStream modSum
         return toks
 
     putStrLn (intercalate "\n" [showToks t])
