@@ -6,9 +6,9 @@ import Language.Haskell.TH
 foo1 x = x
 
 
-test_foo :: Q (TExp (a -> a))
+test_foo :: Code Q (a -> a)
 test_foo = [|| foo1 ||]
 
 
-list_foo :: Q (TExp a) -> Q (TExp [a])
+list_foo :: Code Q a -> Code Q [a]
 list_foo x = [|| [ $$x, $$x ] ||]
