@@ -4,6 +4,6 @@ module TH_Roles1 where
 
 import Language.Haskell.TH
 
-$( return [ DataD [] (mkName "T") [PlainTV (mkName "a") ()] Nothing [] []
+$( return [ DataD [] (mkName "T") [PlainTV (mkName "a") BndrReq] Nothing [] []
           , RoleAnnotD (mkName "T") [RepresentationalR] ] )
 
