@@ -1,3 +1,5 @@
+{-# LANGUAGE TypeAbstractions #-}
+
 module T20443a where
 
 import Data.Kind
@@ -10,4 +12,4 @@ a :: () -> Proxy Int
 a () = Proxy @Int
 
 b :: Proxy Int -> ()
-b (Proxy @Int) = ()       -- This should compile, but doesn't
+b (Proxy @Int) = ()
