@@ -1,4 +1,3 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE RankNTypes #-}
 {-# LANGUAGE TypeFamilies #-}
 {-# LANGUAGE PolyKinds #-}
@@ -6,5 +5,6 @@ module T14904a where
 
 import Data.Kind
 
-type family F (f :: forall a. g a) :: Type where
+type F :: (forall a. g a) -> Type
+type family F f :: Type where
   F (f :: forall a. g a) = Int
