@@ -7,7 +7,6 @@ import Control.Monad (ap, liftM)
 newtype StateT s m a = StateT { runStateT :: s -> m (a,s) }
 
 instance Monad m => Monad (StateT s m) where
-    return a = StateT $ \s -> return (a, s)
     m >>= k  = StateT $ \s -> do
         ~(a, s') <- runStateT m s
         runStateT (k a) s'
@@ -19,7 +18,7 @@ instance Monad m => Functor (StateT s m) where
     fmap = liftM
 
 instance Monad m => Applicative (StateT s m) where
-    pure  = return
+    pure a = StateT $ \s -> pure (a, s)
     (<*>) = ap
 
 get :: Monad m => StateT s m s
